;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "git-modes" "20251101.2017"
  "Major modes for editing Git configuration files."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/magit/git-modes"
  :commit "dfc450d79498b7997b1155ac76629ab01f7ef355"
  :revdesc "dfc450d79498"
  :keywords '("convenience" "vc" "git")
  :authors '(("Sebastian Wiesner" . "lunaryorn@gmail.com")
             ("Rüdiger Sonderfeld" . "ruediger@c-plusplus.net")
             ("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev")))
